#!/bin/sh


# -------------------------------------------------------------------------|
# Setting global variables                                                 |
# -------------------------------------------------------------------------|
cur_dir=$(cd -P -- "$(dirname -- "$0")" && pwd -P)
source $cur_dir/install.properties

water_portal_ear_dir=$was_profile_directory/installedApps/cell1/water_portal_ear.ear
timestamp=$(date +%Y%m%d-%H%M)

declare adminAccount
declare adminPassword


# -------------------------------------------------------------------------|
# Prints the error and exits if rc is not zero                             |
# -------------------------------------------------------------------------|
function if_error_print_and_exit(){
    local i rc=$1
    local error=$2
    if [ $rc -ne 0 ] 
    then 
        echo "$error"
        exit 1
    fi
}


# -------------------------------------------------------------------------|
# Getting the input parameter values                                       |
# -------------------------------------------------------------------------|
while getopts 'u:p:' OPTION
do
	case $OPTION in
	u)  adminAccount="$OPTARG"
		;;
	p)  adminPassword="$OPTARG"
		;;
	?)
        if_error_print_and_exit 1 "WAS admin username and password required: E.g. ./install.sh -u admin -p password1"
        ;;			
	esac	
done


# -------------------------------------------------------------------------|
# Ensuring WAS username and password provided                              |
# -------------------------------------------------------------------------|
if [ -z $adminAccount ] || [ -z $adminPassword ]
then
    if_error_print_and_exit 1 "WAS admin username and password required: E.g. ./install.sh -u admin -p password1"
fi


# -------------------------------------------------------------------------|
# Checking credentials                                                     |
# -------------------------------------------------------------------------|
$was_profile_directory/bin/wsadmin.sh -user $adminAccount -password $adminPassword -lang jython -f $cur_dir/get_cell.py
if [ $? -ne 0 ]
then
    if_error_print_and_exit 1 "Incorrect WAS admin username or password."
fi


# -------------------------------------------------------------------------|
# Stopping the Portal                                                      |
# -------------------------------------------------------------------------|
$was_profile_directory/bin/wsadmin.sh -user $adminAccount -password $adminPassword -lang jython -f $cur_dir/stop_water_portal_ear.py



# -------------------------------------------------------------------------|
# Adding the APAR fix tag                                                  |
# -------------------------------------------------------------------------|
\cp -rf $cur_dir/../apar/Intelligent_Operations_for_Water_PO05958.fxtag /opt/IBM/ioc/properties/version
if_error_print_and_exit $? "Install failed while adding the APAR fix tag"


# -------------------------------------------------------------------------|
# Backing up and replacing water_widgets_web.war with APAR version         |
# -------------------------------------------------------------------------|
mv $water_portal_ear_dir/water_widgets_web.war $cur_dir/../backup/water_widgets_web.war.$timestamp
if_error_print_and_exit $? "Install failed to backup water_widgets_web.war"

cp -r $cur_dir/../apar/water_widgets_web.war $water_portal_ear_dir
if_error_print_and_exit $? "Install failed to copy the new water_widgets_web.war to the water_portal_ear.ear dir"


# -------------------------------------------------------------------------|
# Unzipping the new water_widgets_web.war                                  |
# -------------------------------------------------------------------------|
cd $water_portal_ear_dir
unzip -q -o water_widgets_web.war -d water_widgets_web
if_error_print_and_exit $? "Install failed to unzip water_widgets_web.war"

rm -rf water_widgets_web.war
mv water_widgets_web water_widgets_web.war
if_error_print_and_exit $? "Install failed to rename the unzipped water_widgets_web to water_widgets_web.war"

chown ibmadmin:ibmadmins -R $water_portal_ear_dir/water_widgets_web.war

# -------------------------------------------------------------------------|
# Restarting the Portal                                                    |
# -------------------------------------------------------------------------|
$was_profile_directory/bin/wsadmin.sh -user $adminAccount -password $adminPassword -lang jython -f $cur_dir/start_water_portal_ear.py

echo "Install completed successfully"